@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 57384 2008-12-17 04:28:54Z CJP $"
-__revision__ = "$Revision: 57384 $"
+__svnid__ = "$Id: Editra.py 57795 2009-01-02 21:47:50Z CJP $"
+__revision__ = "$Revision: 57795 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -271,8 +271,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 break
 
         if awin is None:
-            if len(self.GetMainWindows()):
-                awin = self.GetMainWindows()[0]
+            awin = self.GetTopWindow()
+            if awin is None or getattr(awin, '__name__', '?') != "MainWindow":
+                if len(self.GetMainWindows()):
+                    awin = self.GetMainWindows()[0]
 
         return awin
 
@@ -373,6 +375,12 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 encoding = sys.getfilesystemencoding()
                 window.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN,
                               ed_txt.DecodeString(filename, encoding))
+
+                # Make sure the window is brought to the front
+                if window.IsIconized():
+                    window.Iconize(False)
+                window.Raise()
+
             except Exception, msg:
                 self._log("[app][err] Failed to open drop file: %s" % str(msg))
                 pass
@@ -644,8 +652,9 @@ def InitConfig():
             if isinstance(profiler.Profile_Get('PRINT_MODE'), basestring):
                 profiler.Profile_Set('PRINT_MODE', ed_glob.PRINT_BLACK_WHITE)
 
-            # Simplifications to eol mode persistance (0.4.0)
-            TranslateEOLMode()
+            # Simplifications to eol mode persistance (0.4.28)
+            # Keep for now till plugins are updated
+            #profiler.Profile_Del('EOL') # changed to EOL_MODE
 
             #---- End Temporary Profile Adaptions ----#
 
@@ -681,18 +690,17 @@ def InitConfig():
 
         # Set default eol for windows
         if wx.Platform == '__WXMSW__':
-            profiler.Profile_Set('EOL', 'CRLF')
+            profiler.Profile_Set('EOL_MODE', ed_glob.EOL_MODE_CRLF)
             profiler.Profile_Set('ICONSZ', (16, 16))
 
     #---- Profile Loaded / Installed ----#
 
-    # Extra Adaption checks
-    TranslateEOLMode()
-    # End Extra Adaptions
-
     # Set debug mode
-    if 'DEBUG' in profiler.Profile_Get('MODE'):
+    emode = profiler.Profile_Get('MODE')
+    if 'DEBUG' in emode:
         ed_glob.DEBUG = True
+        if emode.startswith('VERBOSE'):
+            ed_glob.VDEBUG = True
 
     # Resolve resource locations
     ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
@@ -769,19 +777,6 @@ def UpgradeOldInstall():
 
 #--------------------------------------------------------------------------#
 
-def TranslateEOLMode():
-    """Translate old eol mode persistance to new one
-    @prerequisite: Profile has been initialized / loaded
-
-    """
-    eol_m = profiler.Profile_Get('EOL')
-    if len(eol_m) > 4:
-        emap = { 'm' : 'CR', 'w' : 'CRLF', 'u' : 'LF' }
-        cmode = eol_m[0].lower()
-        profiler.Profile_Set('EOL', emap.get(cmode, 'LF'))
-
-#--------------------------------------------------------------------------#
-
 def PrintHelp():
     """Print command line help
     @postcondition: Help is printed and program exits
@@ -791,7 +786,7 @@ def PrintHelp():
        "Cody Precord (2005-2008)\n\n"
        "usage: Editra [arguments] [files... ]\n\n"
        "Short Arguments:\n"
-       "  -d         Turn on console debugging\n"
+       "  -d         Turn on console debugging (-dd for verbose debug)\n"
        "  -D         Turn off console debugging (overrides preferences)\n"
        "  -h         Show this help message\n"
        "  -p         Run Editra in the profiler\n"
@@ -827,10 +822,14 @@ def ProcessCommandLine():
             print ed_glob.VERSION
             os._exit(0)
         elif opt in ['-d', '--debug'] and '-D' not in opts:
+            # If the debug flag is set more than once go into verbose mode
+            if ed_glob.DEBUG:
+                ed_glob.VDEBUG = True
             ed_glob.DEBUG = True
             opts.remove(opt)
         elif opt == '-D':
             ed_glob.DEBUG = False
+            ed_glob.VDEBUG = False
             opts.remove('-D')
         elif opt == '-S':
             ed_glob.SINGLE = False # Disable single instance checker
@@ -908,6 +907,7 @@ def _Main(opts, args):
         splash = wx.SplashScreen(splash_img, wx.SPLASH_CENTRE_ON_PARENT | \
                                  wx.SPLASH_NO_TIMEOUT, 0, None, wx.ID_ANY)
         splash.Show()
+        wx.CallLater(2500, splash.Destroy)
 
     if profiler.Profile_Get('SET_WSIZE'):
         wsize = profiler.Profile_Get('WSIZE')
@@ -930,9 +930,6 @@ def _Main(opts, args):
     if wx.Platform == '__WXMSW__':
         wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
 
-    if 'splash' in locals():
-        splash.Destroy()
-
     # Do update check, only check if its been more than a day since the last
     # check
     if profiler.Profile_Get('CHECKUPDATE', default=True):
