@@ -16,13 +16,17 @@ deduct the requested information.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 57423 2008-12-18 19:26:41Z CJP $"
-__revision__ = "$Revision: 57423 $"
+__cvsid__ = "$Id: pycomp.py 57700 2008-12-31 22:44:51Z CJP $"
+__revision__ = "$Revision: 57700 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
-import os, sys, tokenize, types
+import os
+import sys
+import tokenize
+import types
 from token import NAME, DEDENT, STRING, NEWLINE
+
 import wx
 from wx.py import introspect
 
@@ -45,8 +49,8 @@ class Completer(object):
         self._log = wx.GetApp().GetLog()
         self._buffer = stc_buffer
         self._autocomp_keys = [ord('.'),]
-        self._autocomp_stop = ' \'"\\`)'
-        self._autocomp_fillup = '.,;:([]}<>%^&+-=*/|'
+        self._autocomp_stop = ' \'"\\`):'
+        self._autocomp_fillup = '.,;([]}<>%^&+-=*/|'
         self._calltip_keys = [ord('('),]
         self._calltip_cancel = [ord(')'), wx.WXK_RETURN]
         self._case_sensitive = False
@@ -95,7 +99,8 @@ class Completer(object):
                 return sigs
 
         except Exception, msg:
-            self._log("[pycomp][err] %s" % str(msg))
+            self._log("[pycomp][err] _GetCompletionInfo: %s, %s" % \
+                      (sys.exc_info()[0], sys.exc_info()[1]))
             return ''
 
     def GetAutoCompKeys(self):
@@ -205,13 +210,13 @@ class PyCompleter(object):
         try: 
             exec src in self.compldict
         except Exception, msg:
-            dbg("[pycomp][exec err]: src exec: %s" % msg)
+            dbg("[pycomp][err] src exec: %s" % msg)
 
         for loc in scope.locals:
             try: 
                 exec loc in self.compldict
             except Exception, msg:
-                dbg("[pycomp][local err]: local exec %s [%s]" % (msg, loc))
+                dbg("[pycomp][err] local exec %s [%s]" % (msg, loc))
 
     def get_arguments(self, func_obj):
         """Get the arguments of a given function obj
@@ -326,11 +331,17 @@ class PyCompleter(object):
                             # NOTE: when result is none compdict is a list
                             inst = meth #compdict[meth]
                         else:
-                            inst = getattr(result, meth)
+                            inst = getattr(result, meth, None)
 
-                        doc = getattr(inst, '__doc__', None)
-                        if doc is None:
-                            doc = max(getattr(result, '__doc__', ' '), ' ')
+                        # TODO: necessary check to handle some odd swig related
+                        #       errors. Find out why type 'swigvarlink' causes
+                        #       the exception Unknown C global variable.
+                        if len(dir(inst)):
+                            doc = getattr(inst, '__doc__', None)
+                            if doc is None:
+                                doc = max(getattr(result, '__doc__', ' '), ' ')
+                        else:
+                            doc = ' '
 
                         comp = {'word' : meth,
                                 'abbr' : meth,
@@ -350,8 +361,7 @@ class PyCompleter(object):
                             comp['abbr'] += '('
                         completions.append(comp)
                 except Exception, msg:
-                    dbg("[pycomp][err] inner completion: %s [stmt='%s']:" % \
-                        (msg, stmt))
+                    dbg("[pycomp][err] inner completion: %s [stmt='%s']:" % (msg, stmt))
 
             return completions
         except Exception, msg:
@@ -390,14 +400,17 @@ class Scope(object):
         @param docstr: Docstring to format and set
 
         """
-        dstr = docstr.replace('\n',' ')
-        dstr = dstr.replace('\t',' ')
-        while dstr.find('  ') > -1: 
-            dstr = dstr.replace('  ',' ')
-        while dstr[0] in '"\'\t ':
-            dstr = dstr[1:]
-        while dstr[-1] in '"\'\t ':
-            dstr = dstr[:-1]
+        dstr = docstr.replace('\n', ' ')
+        dstr = dstr.replace('\t', ' ')
+        dstr = dstr.replace('  ', ' ')
+
+        if len(dstr):
+            while len(dstr) and dstr[0] in '"\' ':
+                dstr = dstr[1:]
+
+            while len(dstr) and dstr[-1] in '"\' ':
+                dstr = dstr[:-1]
+
         self.docstr = dstr
 
     def local(self, loc):
@@ -433,12 +446,13 @@ class Scope(object):
         @return: string
 
         """
-        # we need to start with this, to fix up broken completions
-        # hopefully this name is unique enough...
         cstr = '"""' + self.docstr + '"""\n'
         for loc in self.locals:
-            if loc.startswith('import'):
+            if loc.startswith('import') or loc.startswith('from'):
                 cstr += loc + '\n'
+
+        # we need to start with this, to fix up broken completions
+        # hopefully this name is unique enough...
         cstr += 'class _PyCmplNoType:\n    def __getattr__(self,name):\n        return None\n'
 
         for sub in self.subscopes:
@@ -706,7 +720,7 @@ class PyParser:
                    'open' : 'file', 'file' : 'file',
                    # List
                    '[' : '[]', 'list' : '[]',
-                   'dir' : '[]', 'zip' : '[]', 'map' : '[]',
+                   'dir' : '["",""]', 'zip' : '[]', 'map' : '[]',
                    'sorted' : '[]', 'range' : '[]',
                    # NoneType
                    'None' : '_PyCmplNoType()',
@@ -733,24 +747,36 @@ class PyParser:
             # NOTE: This part of the parse is where the problem is happening
             assign += token
             level = 0
+            tstack = list()
             while True:
                 tokentype, token = self.next()[:-1]
+#                tstack.append((assign, token, level))
                 if token in ('(', '{', '['):
-                    level += 1
+                    level = level + 1
                 elif token in (']', '}', ')'):
-                    level -= 1
-                    if level == 0:
+                    level = level - 1
+                    if level == 0 or level == -1:
                         break
                 elif level == 0:
+                    # end of line
                     if token in (';', '\n'):
                         break
-                    assign += token
+                    elif token == ',':
+                        assign = ''
+                    else:
+                        assign += token
 
         # Check syntax to filter out bad tokens
         # NOTE: temporary till parser is improved more
         try:
             compile(assign, '_pycomp', 'eval')
         except:
+#            print ""
+#            for t in tstack:
+#                print t
+#            print assign
+#            print ""
+#            print ""
             dbg("[pycomp][err] parseassignment bad token: %s" % assign)
             return None
         else:
@@ -861,6 +887,7 @@ class PyParser:
                             loc += " as %s" % alias
                         self.scope.local(loc)
                     freshscope = False
+
                 elif tokentype == STRING:
                     if freshscope:
                         self.scope.doc(token)
