@@ -12,8 +12,8 @@ Tools and Utilities for debugging and helping with development of Editra.
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 56809 2008-11-17 02:15:33Z CJP $"
-__revision__ = "$Revision: 56809 $"
+__svnid__ = "$Id: dev_tool.py 57699 2008-12-31 20:27:56Z CJP $"
+__revision__ = "$Revision: 57699 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -78,9 +78,16 @@ def DEBUGP(statement):
         mstr = unicode(msg)
         print mstr.encode('utf-8', 'replace')
 
+        # Check for trapped exceptions to print
+        if ed_glob.VDEBUG and msg.Type in ('err', 'error'):
+            traceback.print_exc()
+
     # Dispatch message to all interested parties
     if msg.Type in ('err', 'error'):
         mtype = ed_msg.EDMSG_LOG_ERROR
+        if ed_glob.VDEBUG:
+            msg = LogMsg(msg.Value + os.linesep + traceback.format_exc(),
+                         msg.Origin, msg.Type)
     elif msg.Type in ('warn', 'warning'):
         mtype = ed_msg.EDMSG_LOG_WARN
     elif msg.Type in ('evt', 'event'):
@@ -94,7 +101,7 @@ def DEBUGP(statement):
 
 #-----------------------------------------------------------------------------#
 
-class LogMsg:
+class LogMsg(object):
     """LogMsg is a container class for representing log messages. Converting
     it to a string will yield a formatted log message with timestamp. Once a
     message has been displayed once (converted to a string) it is marked as
@@ -108,6 +115,8 @@ class LogMsg:
         @keyword level: Priority of the message
 
         """
+        object.__init__(self)
+
         # Attributes
         self._msg = dict(mstr=msg, msrc=msrc, lvl=level, tstamp=time.time())
         self._ok = True
@@ -257,10 +266,7 @@ def TimeStamp():
 
 class ErrorReporter(object):
     """Crash/Error Reporter Service
-    @summary: Stores all errors caught during the current session and
-              is implemented as a singleton so that all errors pushed
-              onto it are kept in one central location no matter where
-              the object is called from.
+    @summary: Stores all errors caught during the current session.
 
     """
     instance = None
@@ -300,7 +306,7 @@ class ErrorReporter(object):
         @return: formatted log message of errors
 
         """
-        return "\n\n".join(self._sessionerr)
+        return (os.linesep * 2).join(self._sessionerr)
 
     def GetLastError(self):
         """Gets the last error from the current session
