@@ -14,8 +14,8 @@ Text editor buffer view control for the main notebook
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_editv.py 56548 2008-10-28 12:30:18Z CJP $"
-__revision__ = "$Revision: 56548 $"
+__svnid__ = "$Id: ed_editv.py 57710 2009-01-01 23:00:10Z CJP $"
+__revision__ = "$Revision: 57710 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -24,6 +24,7 @@ import os
 
 # Editra Libraries
 import ed_glob
+import ed_menu
 import ed_stc
 import ed_tab
 from doctools import DocPositionMgr
@@ -46,20 +47,29 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         ed_stc.EditraStc.__init__(self, parent, id_, pos, size, style, use_dt)
         ed_tab.EdTabBase.__init__(self, parent)
 
+        # Attributes
+        self._menu = MakeMenu()
+
         # Initialize the classes position manager for the first control
         # that is created only.
         if not EdEditorView.DOCMGR.IsInitialized():
             EdEditorView.DOCMGR.InitPositionCache(ed_glob.CONFIG['CACHE_DIR'] + \
                                                   os.sep + u'positions')
 
+        # Context Menu Events
+        self.Bind(wx.EVT_CONTEXT_MENU, lambda evt: self.PopupMenu(self._menu))
+
+    #---- EdTab Methods ----#
+
     def DoOnIdle(self):
         """Check if the file has been modified and prompt a warning"""
         if Profile_Get('CHECKMOD'):
             cfile = self.GetFileName()
             lmod = GetFileModTime(cfile)
-            if self.GetModTime() and not lmod and not os.path.exists(cfile):
+            mtime = self.GetModTime()
+            if mtime and not lmod and not os.path.exists(cfile):
                 wx.CallAfter(self.PromptToReSave, cfile)
-            elif self.GetModTime() < lmod:
+            elif mtime < lmod:
                 wx.CallAfter(self.AskToReload, cfile)
             else:
                 pass
@@ -86,6 +96,24 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
         """
         return u"EditraTextCtrl"
 
+    def GetTabMenu(self):
+        """Get the tab menu
+        @return: wx.Menu
+        @todo: move logic from notebook to here
+
+        """
+        ptxt = self.GetTabLabel()
+
+        menu = ed_menu.EdMenu()
+        menu.Append(ed_glob.ID_NEW, _("New Tab"))
+        menu.AppendSeparator()
+        menu.Append(ed_glob.ID_SAVE, _("Save \"%s\"") % ptxt)
+        menu.Append(ed_glob.ID_CLOSE, _("Close \"%s\"") % ptxt)
+        menu.Append(ed_glob.ID_CLOSEALL, _("Close All"))
+        menu.AppendSeparator()
+        menu.Append(ed_glob.ID_COPY_PATH, _("Copy Full Path"))
+        return menu
+
     def GetTitleString(self):
         """Get the title string to display in the MainWindows title bar
         @return: (unicode) string
@@ -116,6 +144,8 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
 
         return result
 
+    #---- End EdTab Methods ----#
+
     def PromptToReSave(self, cfile):
         """Show a dialog prompting to resave the current file
         @param cfile: the file in question
@@ -163,3 +193,21 @@ class EdEditorView(ed_stc.EditraStc, ed_tab.EdTabBase):
                 mdlg.Destroy()
         else:
             self.SetModTime(GetFileModTime(cfile))
+
+#-----------------------------------------------------------------------------#
+
+def MakeMenu():
+    """Make the buffers context menu"""
+    menu = ed_menu.EdMenu()
+    menu.Append(ed_glob.ID_UNDO, _("Undo"))
+    menu.Append(ed_glob.ID_REDO, _("Redo"))
+    menu.AppendSeparator()
+    menu.Append(ed_glob.ID_CUT, _("Cut"))
+    menu.Append(ed_glob.ID_COPY, _("Copy"))
+    menu.Append(ed_glob.ID_PASTE, _("Paste"))
+    menu.AppendSeparator()
+    menu.Append(ed_glob.ID_TO_UPPER, _("To Uppercase"))
+    menu.Append(ed_glob.ID_TO_LOWER, _("To Lowercase"))
+    menu.AppendSeparator()
+    menu.Append(ed_glob.ID_SELECTALL, _("Select All"))
+    return menu
