@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 57415 2008-12-18 05:02:07Z CJP $"
-__revision__ = "$Revision: 57415 $"
+__svnid__ = "$Id: ed_glob.py 57676 2008-12-30 20:40:41Z CJP $"
+__revision__ = "$Revision: 57676 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -31,8 +31,8 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_GOTO_LINE', 'ID_NEXT_MARK', 'ID_PRE_MARK', 'ID_FONT',
             'ID_EOL_MAC', 'ID_EOL_UNIX', 'ID_EOL_WIN', 'ID_WORD_WRAP',
             'ID_INDENT', 'ID_UNINDENT', 'ID_TO_UPPER', 'ID_TO_LOWER',
-            'ID_SPACE_TO_TAB', 'ID_TAB_TO_SPACE', 'ID_TRIM_WS', 'ID_COMMENT',
-            'ID_UNCOMMENT', 'ID_AUTOCOMP', 'ID_AUTOINDENT', 'ID_SYNTAX',
+            'ID_SPACE_TO_TAB', 'ID_TAB_TO_SPACE', 'ID_TRIM_WS',
+            'ID_TOGGLECOMMENT', 'ID_AUTOCOMP', 'ID_AUTOINDENT', 'ID_SYNTAX',
             'ID_FOLDING', 'ID_BRACKETHL', 'ID_LEXER', 'ID_KWHELPER',
             'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 'ID_MACRO_STOP',
             'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 'ID_CONTACT',
@@ -40,7 +40,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
             'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE', 'ID_SHOW_SB',
             'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP', 'ID_PASTE_AFTER',
-            'ID_COLUMN_MODE', 'ID_PANELIST', 'ID_NEW_WINDOW']
+            'ID_COLUMN_MODE', 'ID_PANELIST', 'ID_NEW_WINDOW', 'ID_TOGGLE_FOLD']
 
 #---- Project Info ----#
 # The project info was moved to another module so it could be accessed
@@ -54,6 +54,8 @@ from info import *
 #---- Imported Libs/Objects ----#
 import wx
 
+_ = wx.GetTranslation
+
 #---- WX Compatibility Hacks ----#
 import wxcompat
 
@@ -73,7 +75,9 @@ CONFIG = {
           'TEST_DIR'    : "",   # Test data files dir
 }
 
+# Global logging/application variables
 DEBUG = False
+VDEBUG = False
 SINGLE = True
 
 #---- Object ID's ----#
@@ -155,6 +159,7 @@ ID_PRINT_MODE    = wx.NewId()
 ID_TRANSPARENCY  = wx.NewId()
 ID_PREF_SPOS     = wx.NewId()
 ID_PREF_UPDATE_BAR = wx.NewId()
+ID_PREF_WARN_EOL = wx.NewId()
 ID_SESSION       = wx.NewId()
 
 # View Menu IDs
@@ -175,6 +180,7 @@ ID_SHELF         = wx.NewId()
 ID_PANELIST      = wx.NewId()
 ID_GOTO_LINE     = wx.NewId()
 ID_GOTO_MBRACE   = wx.NewId()
+ID_TOGGLE_FOLD   = wx.NewId()
 ID_NEXT_MARK     = wx.ID_FORWARD
 ID_PRE_MARK      = wx.ID_BACKWARD
 
@@ -194,8 +200,7 @@ ID_WS_FORMAT     = wx.NewId()
 ID_SPACE_TO_TAB  = wx.NewId()
 ID_TAB_TO_SPACE  = wx.NewId()
 ID_TRIM_WS       = wx.NewId()
-ID_COMMENT       = wx.NewId()
-ID_UNCOMMENT     = wx.NewId()
+ID_TOGGLECOMMENT = wx.NewId()
 
 # Settings Menu IDs
 ID_AUTOCOMP      = wx.NewId()
@@ -281,53 +286,64 @@ PRINT_NORMAL      = 4
 # Dictionary to map object ids to Profile keys
 ID_2_PROF = {
              ID_PREF_AALIAS       : 'AALIASING',
+             ID_TRANSPARENCY      : 'ALPHA',
+             ID_PREF_UNINDENT     : 'BSUNINDENT',
              ID_APP_SPLASH        : 'APPSPLASH',
              ID_AUTOCOMP          : 'AUTO_COMP',
              ID_AUTOINDENT        : 'AUTO_INDENT',
+             ID_PREF_AUTOTRIM     : 'AUTO_TRIM_WS',
              ID_BRACKETHL         : 'BRACKETHL',
              ID_PREF_CHKMOD       : 'CHECKMOD',
              ID_PREF_CHKUPDATE    : 'CHECKUPDATE',
              ID_FOLDING           : 'CODE_FOLD',
-             ID_PERSPECTIVES      : 'DEFAULT_VIEW',
-             ID_KWHELPER          : 'KWHELPER',
-             ID_EOL_MODE          : 'EOL',
-             ID_PREF_FHIST        : 'FHIST_LVL',
-             ID_HLCARET_LINE      : 'HLCARETLINE',
-             ID_INDENT_GUIDES     : 'GUIDES',
-             ID_KEY_PROFILES      : 'KEY_PROFILE',
-             ID_PREF_LANG         : 'LANG',
-             ID_REPORTER          : 'REPORTER',
-             ID_SYNTAX            : 'SYNTAX',
-             ID_PREF_AUTOTRIM     : 'AUTO_TRIM_WS',
              ID_PREF_DLEXER       : 'DEFAULT_LEX',
+             ID_PERSPECTIVES      : 'DEFAULT_VIEW',
+             ID_PREF_EDGE         : 'EDGE',
              ID_PREF_ENCODING     : 'ENCODING',
-             ID_PREF_SYNTHEME     : 'SYNTHEME',
-             ID_PREF_TABS         : 'USETABS',
-             ID_PREF_UNINDENT     : 'BSUNINDENT',
-             ID_PREF_TABICON      : 'TABICONS',
-             ID_PREF_TABW         : 'TABWIDTH',
+             ID_EOL_MODE          : 'EOL_MODE',
+             ID_PREF_FHIST        : 'FHIST_LVL',
+             ID_INDENT_GUIDES     : 'GUIDES',
+             ID_HLCARET_LINE      : 'HLCARETLINE',
+             ID_PREF_ICON         : 'ICONS',
+             ID_PREF_ICONSZ       : 'ICON_SZ',
              ID_PREF_INDENTW      : 'INDENTWIDTH',
+             ID_KEY_PROFILES      : 'KEY_PROFILE',
+             ID_KWHELPER          : 'KWHELPER',
+             ID_PREF_LANG         : 'LANG',
+             ID_PREF_MODE         : 'MODE',
+             ID_NEW_WINDOW        : 'OPEN_NW',
+             ID_PRINT_MODE        : 'PRINT_MODE',
+             ID_REPORTER          : 'REPORTER',
+             ID_PREF_SPOS         : 'SAVE_POS',
              ID_SESSION           : 'SAVE_SESSION',
+             ID_PREF_WPOS         : 'SET_WPOS',
+             ID_PREF_WSIZE        : 'SET_WSIZE',
              ID_SHOW_EDGE         : 'SHOW_EDGE',
              ID_SHOW_EOL          : 'SHOW_EOL',
              ID_SHOW_LN           : 'SHOW_LN',
              ID_SHOW_WS           : 'SHOW_WS',
-             ID_TRANSPARENCY      : 'ALPHA',
-             ID_WORD_WRAP         : 'WRAP',
-             ID_PREF_EDGE         : 'EDGE',
-             ID_PREF_SPOS         : 'SAVE_POS',
-             ID_PREF_WSIZE        : 'SET_WSIZE',
-             ID_PREF_WPOS         : 'SET_WPOS',
-             ID_PREF_ICON         : 'ICONS',
-             ID_PREF_ICONSZ       : 'ICON_SZ',
-             ID_PREF_MODE         : 'MODE',
-             ID_PRINT_MODE        : 'PRINT_MODE',
-             ID_NEW_WINDOW        : 'OPEN_NW',
              ID_SHOW_SB           : 'STATBAR',
+             ID_SYNTAX            : 'SYNTAX',
+             ID_PREF_SYNTHEME     : 'SYNTHEME',
+             ID_PREF_TABICON      : 'TABICONS',
+             ID_PREF_TABW         : 'TABWIDTH',
+             ID_VIEW_TOOL         : 'TOOLBAR',
+             ID_PREF_TABS         : 'USETABS',
              ID_VI_MODE           : 'VI_EMU',
-             ID_VIEW_TOOL         : 'TOOLBAR'
+             ID_PREF_WARN_EOL     : 'WARN_EOL',
+             ID_WORD_WRAP         : 'WRAP',
 }
 
+EOL_MODE_CR   = 0
+EOL_MODE_LF   = 1
+EOL_MODE_CRLF = 2
+def EOLModeMap():
+    """Get the eol mode map"""
+    # Maintenance Note: ints must be kept in sync with EDSTC_EOL_* in edstc 
+    return { EOL_MODE_CR : _("Old Machintosh") + u" (\\r)",
+             EOL_MODE_LF : _("Unix") + u" (\\n)",
+             EOL_MODE_CRLF : _("Windows") + u" (\\r\\n)"}
+
 # Default Plugins
 DEFAULT_PLUGINS = ("generator.Html", "generator.LaTeX", "generator.Rtf",
                    "iface.Shelf", "ed_theme.TangoTheme", "ed_log.EdLogViewer",
