@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 57415 2008-12-18 05:02:07Z CJP $"
-__revision__ = "$Revision: 57415 $"
+__svnid__ = "$Id: ed_main.py 57795 2009-01-02 21:47:50Z CJP $"
+__revision__ = "$Revision: 57795 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -160,6 +160,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        # Edit Menu
                                        (ID_PASTE_AFTER, self.DispatchToControl),
                                        (ID_COLUMN_MODE, self.DispatchToControl),
+                                       (ID_TOGGLE_FOLD, self.DispatchToControl),
                                        (ID_QUICK_FIND, self.OnCommandBar),
                                        (ID_PREF, OnPreferences),
 
@@ -307,13 +308,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
             for handler in self._handlers['ui']:
                 app.AddUIHandlerForID(*handler)
+
+            app.SetTopWindow(self)
         else:
             self.SetExtraStyle(0)
 
             # HACK set update ui events back to proccess all here in case
             # opened dialog needs them. Not sure why this is necessary but it
             # is the only solution I could find to fix the external find
-            # dialogs so that there buttons become enabled when typing in the
+            # dialogs so that their buttons become enabled when typing in the
             # text control.
             #
             # If the windows that took the active position is another mainwindow
@@ -326,6 +329,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
             for handler in self._handlers['ui']:
                 app.RemoveUIHandlerForID(handler[0])
+
+            self._loaded = False
+
         evt.Skip()
 
     def AddFileToHistory(self, fname):
@@ -927,10 +933,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         ctrl = self.nb.GetCurrentCtrl()
         active_only = [ ID_ZOOM_IN, ID_ZOOM_OUT, ID_ZOOM_NORMAL,
                         ID_JOIN_LINES, ID_CUT_LINE, ID_COPY_LINE, ID_INDENT,
-                        ID_UNINDENT, ID_TRANSPOSE, ID_COMMENT, ID_UNCOMMENT,
+                        ID_UNINDENT, ID_TRANSPOSE, ID_TOGGLECOMMENT,
                         ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY,
                         ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE,
-                        ID_PASTE_AFTER, ID_COLUMN_MODE ]
+                        ID_PASTE_AFTER, ID_COLUMN_MODE, ID_TOGGLE_FOLD ]
 
         has_focus = self.FindFocus()
         if has_focus != ctrl and e_id in active_only:
