@@ -14,8 +14,8 @@ for managing keybindings and profiles is also provided by this module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 57422 2008-12-18 17:44:54Z CJP $"
-__revision__ = "$Revision: 57422 $"
+__svnid__ = "$Id: ed_menu.py 57629 2008-12-29 04:55:41Z CJP $"
+__revision__ = "$Revision: 57629 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -662,6 +662,7 @@ class EdMenuBar(wx.MenuBar):
                         _("Show Whitespace Markers"), wx.ITEM_CHECK)
         viewmenu.AppendSubMenu(self._menus['viewedit'], _("Editor"), \
                                _("Toggle Editor View Options"))
+        viewmenu.AppendSeparator()
         viewmenu.Append(ed_glob.ID_PANELIST, _("Pane Navigator") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_PANELIST),
                         _("View pane selection list"))
@@ -673,6 +674,10 @@ class EdMenuBar(wx.MenuBar):
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_GOTO_MBRACE),
                         _("Move caret matching brace"))
         viewmenu.AppendSeparator()
+        viewmenu.Append(ed_glob.ID_TOGGLE_FOLD, _("Toggle Fold") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_TOGGLE_FOLD),
+                        _("Toggle the current fold in the buffer"))
+        viewmenu.AppendSeparator()
         viewmenu.Append(ed_glob.ID_NEXT_MARK, _("Next Bookmark") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_NEXT_MARK),
                         _("View Line of Next Bookmark"))
@@ -701,12 +706,9 @@ class EdMenuBar(wx.MenuBar):
                           EdMenuBar.keybinder.GetBinding(ed_glob.ID_FONT),
                           _("Change Font Settings"))
         formatmenu.AppendSeparator()
-        formatmenu.Append(ed_glob.ID_COMMENT, _("Comment Lines") + \
-                          EdMenuBar.keybinder.GetBinding(ed_glob.ID_COMMENT),
-                          _("Comment the selected lines"))
-        formatmenu.Append(ed_glob.ID_UNCOMMENT, _("Uncomment Lines") + \
-                          EdMenuBar.keybinder.GetBinding(ed_glob.ID_UNCOMMENT),
-                          _("Uncomment the selected lines"))
+        formatmenu.Append(ed_glob.ID_TOGGLECOMMENT, _("Toggle Comment") + \
+                          EdMenuBar.keybinder.GetBinding(ed_glob.ID_TOGGLECOMMENT),
+                          _("Toggle comment on the selected line(s)"))
         formatmenu.AppendSeparator()
 
 
@@ -1010,14 +1012,14 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_ZOOM_NORMAL : ("Ctrl", "0"),
                      ed_glob.ID_GOTO_LINE : ("Ctrl", "G"),
                      ed_glob.ID_GOTO_MBRACE : ("Ctrl", "Shift", "B"),
+                     ed_glob.ID_TOGGLE_FOLD : ("Ctrl", "Shift", "T"),
                      ed_glob.ID_NEXT_MARK : ("Alt", "Right"), # Win/Linux
                      ed_glob.ID_PRE_MARK : ("Alt", "Left"), # Win/Linux
                      ed_glob.ID_SHOW_SHELF : ("Ctrl", "Alt", "S"),
                      ed_glob.ID_PANELIST : ("Alt", "1"), # Win/Linux
 
                      # Format Menu
-                     ed_glob.ID_COMMENT : ("Ctrl", "1"),
-                     ed_glob.ID_UNCOMMENT : ("Ctrl", "2"),
+                     ed_glob.ID_TOGGLECOMMENT : ("Ctrl", "1"),
                      ed_glob.ID_INDENT : ("Tab",),
                      ed_glob.ID_UNINDENT : ("Shift", "Tab"),
                      ed_glob.ID_USE_SOFTTABS : ("Ctrl", "Shift", "I"),
