@@ -13,8 +13,8 @@ This class implements Editra's main notebook control.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 57362 2008-12-15 20:57:12Z CJP $"
-__revision__ = "$Revision: 57362 $"
+__svnid__ = "$Id: ed_pages.py 57722 2009-01-02 00:39:05Z CJP $"
+__revision__ = "$Revision: 57722 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -33,7 +33,6 @@ import util
 import ed_msg
 import ed_txt
 import ed_mdlg
-import ed_menu
 import eclib.encdlg as encdlg
 from extern import flatnotebook as FNB
 
@@ -206,8 +205,10 @@ class EdPages(FNB.FlatNotebook):
 
     def AddPage(self, page, text, select=True, imgId=-1):
         """Add a page to the notebook"""
-        FNB.FlatNotebook.AddPage(self, page, text, select, imgId)
-        self.EnsureVisible(self.GetSelection())
+        super(EdPages, self).AddPage(page, text, select, imgId)
+        page.SetTabLabel(text)
+        sel = self.GetSelection()
+        self.EnsureVisible(sel)
 
     def DocDuplicated(self, path):
         """Check for if the given path is open elswhere and duplicate the
@@ -400,21 +401,14 @@ class EdPages(FNB.FlatNotebook):
         if self._menu is not None:
             self._menu.Destroy()
             self._menu = None
-        cidx = self.GetSelection()
-        ptxt = self.GetPageText(cidx)
 
         # Construct the menu
-        self._menu = ed_menu.EdMenu()
-        self._menu.Append(ed_glob.ID_NEW, _("New Tab"))
-        self._menu.AppendSeparator()
-        self._menu.Append(ed_glob.ID_SAVE, _("Save \"%s\"") % ptxt)
-        self._menu.Append(ed_glob.ID_CLOSE, _("Close \"%s\"") % ptxt)
-        self._menu.Append(ed_glob.ID_CLOSEALL, _("Close All"))
-        self._menu.AppendSeparator()
-        self._menu.Append(ed_glob.ID_COPY_PATH, _("Copy Full Path"))
-        #self._menu.AppendSeparator()
-        
-        self.PopupMenu(self._menu)
+        ctab = self.GetCurrentPage()
+        if ctab is not None:
+            self._menu = ctab.GetTabMenu()
+
+        if self._menu is not None:
+            self.PopupMenu(self._menu)
 
     def OnThemeChanged(self, msg):
         """Update icons when the theme has changed
@@ -423,6 +417,55 @@ class EdPages(FNB.FlatNotebook):
         """
         self.UpdateAllImages()
 
+    def OpenFileObject(self, fileobj):
+        """Open a new text editor page with the given file object. The file
+        object must be an instance of ed_txt.EdFile.
+        @param fileobj: File Object
+
+        """
+        # Create the control
+        self.GetTopLevelParent().Freeze()
+        control = ed_editv.EdEditorView(self, wx.ID_ANY)
+        control.Hide()
+
+        # Load the files data
+        path = fileobj.GetPath()
+        filename = util.GetFileName(path)
+        control.SetDocument(fileobj)
+        result = control.ReloadFile()
+
+        # Setup the buffer
+        fileobj.AddModifiedCallback(control.FireModified)
+
+        # Setup the notebook
+        self.control = control
+        self.control.FindLexer()
+        self.control.EmptyUndoBuffer()
+        self.control.Show()
+        self.AddPage(self.control, filename)
+
+        self.frame.SetTitle(self.control.GetTitleString())
+        self.frame.AddFileToHistory(path)
+        self.SetPageText(self.GetSelection(), filename)
+        self.LOG("[ed_pages][evt] Opened Page: %s" % filename)
+
+        # Set tab image
+        cpage = self.GetSelection()
+        if fileobj.ReadOnly:
+            super(EdPages, self).SetPageImage(cpage,
+                                              self._index[ed_glob.ID_READONLY])
+        else:
+            self.SetPageImage(cpage, str(self.control.GetLangId()))
+
+        self.GetTopLevelParent().Thaw()
+
+        # Refocus on selected page
+        self.GoCurrentPage()
+        ed_msg.PostMessage(ed_msg.EDMSG_FILE_OPENED, self.control.GetFileName())
+
+        if Profile_Get('WARN_EOL', default=True):
+            self.control.CheckEOL()
+
     def OpenPage(self, path, filename, quiet=False):
         """Open a File Inside of a New Page
         @param path: files base path
@@ -514,7 +557,6 @@ class EdPages(FNB.FlatNotebook):
 
         # Setup Document
         self.control.FindLexer()
-        self.control.CheckEOL()
         self.control.EmptyUndoBuffer()
         doc = self.control.GetDocument()
         doc.AddModifiedCallback(self.control.FireModified)
@@ -536,8 +578,8 @@ class EdPages(FNB.FlatNotebook):
         # Set tab image
         cpage = self.GetSelection()
         if doc.ReadOnly:
-            FNB.FlatNotebook.SetPageImage(self, cpage,
-                                          self._index[ed_glob.ID_READONLY])
+            super(EdPages, self).SetPageImage(cpage,
+                                              self._index[ed_glob.ID_READONLY])
         else:
             self.SetPageImage(cpage, str(self.control.GetLangId()))
 
@@ -546,6 +588,9 @@ class EdPages(FNB.FlatNotebook):
         self.GetTopLevelParent().Thaw()
         ed_msg.PostMessage(ed_msg.EDMSG_FILE_OPENED, self.control.GetFileName())
 
+        if Profile_Get('WARN_EOL', default=True):
+            self.control.CheckEOL()
+
     def GoCurrentPage(self):
         """Move Focus to Currently Selected Page.
         @postcondition: focus is set to current page
@@ -582,7 +627,7 @@ class EdPages(FNB.FlatNotebook):
         # even though the pg_num here is one that is obtained by calling
         # GetSelection which should return a valid index.
         try:
-            txt = FNB.FlatNotebook.GetPageText(self, pg_num)
+            txt = super(EdPages, self).GetPageText(pg_num)
         except IndexError:
             txt = ''
 
@@ -590,6 +635,16 @@ class EdPages(FNB.FlatNotebook):
             return txt
         return txt[1:]
 
+    def SetPageText(self, pg_num, txt):
+        """Set the pages tab text
+        @param pg_num: page index
+        @param txt: string
+
+        """
+        super(EdPages, self).SetPageText(pg_num, txt)
+        page = self.GetPage(pg_num)
+        page.SetTabLabel(txt)
+
     def GetTextControls(self):
         """Gets all the currently opened text controls
         @return: list containing reference to all stc controls opened in the
@@ -675,7 +730,7 @@ class EdPages(FNB.FlatNotebook):
         @type evt: wx.IdleEvent
 
         """
-        if wx.GetApp().IsActive() and self.GetPageCount():
+        if wx.GetApp().IsActive():
             page = self.GetCurrentPage()
             if page is not None:
                 page.DoOnIdle()
@@ -851,7 +906,7 @@ class EdPages(FNB.FlatNotebook):
             else:
                 self._index[lang_id] = imglst.Add(wx.ArtProvider.\
                                               GetBitmap(lang_id, wx.ART_MENU))
-        FNB.FlatNotebook.SetPageImage(self, pg_num, self._index[lang_id])
+        super(EdPages, self).SetPageImage(pg_num, self._index[lang_id])
 
     def UpdateAllImages(self):
         """Reload and Reset all images in the notebook pages and
@@ -862,7 +917,7 @@ class EdPages(FNB.FlatNotebook):
         # If icons preference has been disabled then clear all icons
         if not Profile_Get('TABICONS'):
             for page in xrange(self.GetPageCount()):
-                FNB.FlatNotebook.SetPageImage(self, page, -1)
+                super(EdPages, self).SetPageImage(page, -1)
         else:
             # Reload the image list with new icons from the ArtProvider
             imglst = self.GetImageList()
@@ -904,7 +959,7 @@ class EdPages(FNB.FlatNotebook):
                     title = u"*" + title
 
                 # Only Update if the text has changed
-                if title != FNB.FlatNotebook.GetPageText(self, pg_num):
+                if title != super(EdPages, self).GetPageText(pg_num):
                     self.SetPageText(pg_num, title)
                     ftitle = self.control.GetTitleString()
                     self.frame.SetTitle(ftitle)
@@ -916,7 +971,7 @@ class EdPages(FNB.FlatNotebook):
                         title = self.GetPageText(page)
                         if control.GetModify():
                             title = u"*" + title
-                        if title != FNB.FlatNotebook.GetPageText(self, page):
+                        if title != super(EdPages, self).GetPageText(page):
                             self.SetPageText(page, title)
         except wx.PyDeadObjectError:
             pass
