@@ -16,8 +16,8 @@ highlight text in a StyledTextCtrl.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 57416 2008-12-18 05:30:38Z CJP $"
-__revision__ = "$Revision: 57416 $"
+__svnid__ = "$Id: ed_search.py 57795 2009-01-02 21:47:50Z CJP $"
+__revision__ = "$Revision: 57795 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -66,6 +66,7 @@ class SearchController:
         self._li_choices = list()
         self._li_sel   = 0
         self._filters  = None
+        self._clients = list()
 
         # Event handlers
         self._parent.Bind(finddlg.EVT_FIND, self.OnFind)
@@ -74,6 +75,7 @@ class SearchController:
         self._parent.Bind(finddlg.EVT_REPLACE, self.OnReplace)
         self._parent.Bind(finddlg.EVT_REPLACE_ALL, self.OnReplaceAll)
         self._parent.Bind(finddlg.EVT_FIND_CLOSE, self.OnFindClose)
+        self._parent.Bind(finddlg.EVT_OPTION_CHANGED, self.OnOptionChanged)
 
     def _CreateNewDialog(self, e_id):
         """Create and set the controlers find dialog
@@ -133,6 +135,9 @@ class SearchController:
 
         """
         cbuff = self._stc()
+        if cbuff is None:
+            return u''
+
         start, end = cbuff.GetSelection()
         rtext = cbuff.GetSelectedText()
         if start != end:
@@ -344,6 +349,15 @@ class SearchController:
         self._finddlg = None
         evt.Skip()
 
+    def OnOptionChanged(self, evt):
+        """Handle when the find options are changed in the dialog"""
+        dead = list()
+        for idx, client in enumerate(self._clients):
+            try:
+                client.NotifyOptionChanged(evt)
+            except wx.PyDeadObjectError:
+                dead.append(idx)
+
     def OnReplace(self, evt):
         """Replace the selected text in the current buffer
         @param evt: finddlg.EVT_REPLACE
@@ -436,6 +450,27 @@ class SearchController:
             self._finddlg.Raise()
         self._finddlg.SetFocus()
 
+    def RegisterClient(self, client):
+        """Register a client object of this search controller. The client object
+        must implement a method called NotifyOptionChanged to be called when
+        search options are changed.
+
+        >>> def NotifyOptionChanged(self, evt)
+
+        @param client: object
+
+        """
+        if client not in self._clients:
+            self._clients.append(client)
+
+    def RemoveClient(self, client):
+        """Remove a client from this controller
+        @param client: object
+
+        """
+        if client in self._clients:
+            self._clients.remove(client)
+
     @staticmethod
     def ReplaceInStc(stc, matches, rstring, isregex=True):
         """Replace the strings at the position in the given StyledTextCtrl
@@ -487,6 +522,11 @@ class SearchController:
         if self._finddlg is not None:
             self._finddlg.SetData(self._data)
 
+    def RefreshControls(self):
+        """Refresh controls that are associated with this controllers data."""
+        if self._finddlg is not None:
+            self._finddlg.RefreshFindOptions()
+
 #-----------------------------------------------------------------------------#
 
 class SearchEngine:
@@ -625,9 +665,9 @@ class SearchEngine:
     def GetOptionsString(self):
         """Get a string describing the search engines options"""
         rstring = u"\"%s\" [ " % self._query
-        for desc, attr in ((_("regex: %s"), self._isregex), 
-                          (_("match case: %s"), self._matchcase),
-                          (_("whole word: %s"), self._wholeword)):
+        for desc, attr in ((_("regex: %s"), self._isregex),
+                           (_("match case: %s"), self._matchcase),
+                           (_("whole word: %s"), self._wholeword)):
             if attr:
                 rstring += (desc % u"on; ")
             else:
@@ -651,6 +691,13 @@ class SearchEngine:
         """
         return self._regex
 
+    def GetSearchPool(self):
+        """Get the search pool string for this L{SearchEngine}.
+        @return: string
+
+        """
+        return self._pool
+
     def IsMatchCase(self):
         """Is the engine set to a case sensitive search
         @return: bool
@@ -785,7 +832,7 @@ class SearchEngine:
                           ('_wholeword', wholeword), ('_next', down)):
             if val is not None:
                 setattr(self, attr, val)
-        self._regex = self._CompileRegex()
+        self._CompileRegex()
 
     def SetSearchPool(self, pool):
         """Set the search pool used by the Find methods
@@ -852,6 +899,7 @@ class EdSearchCtrl(wx.SearchCtrl):
         self._last       = None
         self.rmenu       = wx.Menu()
         self.max_menu    = menulen + 2   # Max menu length + descript/separator
+        self._txtctrl    = None          # msw/gtk only
 
         # Setup Recent Search Menu
         lbl = self.rmenu.Append(wx.ID_ANY, _("Recent Searches"))
@@ -864,6 +912,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             for child in self.GetChildren():
                 if isinstance(child, wx.TextCtrl):
                     child.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
+                    self._txtctrl = child
                     break
         else:
             self.Bind(wx.EVT_KEY_UP, self.ProcessEvent)
@@ -889,6 +938,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             c_flags ^= flag
             self._flags = c_flags
             data.SetFlags(self._flags)
+            self.FindService.RefreshControls()
 
     def DoSearch(self, next=True):
         """Do the search and move the selection
@@ -912,16 +962,29 @@ class EdSearchCtrl(wx.SearchCtrl):
 
         # Give feedback on whether text was found or not
         if self.FindService.GetLastFound() < 0 and len(self.GetValue()) > 0:
-            self.SetForegroundColour(wx.RED)
+            if self._txtctrl is None:
+                self.SetForegroundColour(wx.RED)
+            else:
+                self._txtctrl.SetForegroundColour(wx.RED)
             wx.Bell()
         else:
             # ?wxBUG? cant set text back to black after changing color
             # But setting it to this almost black color works. Most likely its
             # due to bit masking but I havent looked at the source so I am not
             # sure
-            self.SetForegroundColour(wx.ColorRGB(0 | 1 | 0))
+            if self._txtctrl is None:
+                self.SetForegroundColour(wx.ColorRGB(0 | 1 | 0))
+            else:
+                self._txtctrl.SetForegroundColour(wx.ColorRGB(0 | 1 | 0))
         self.Refresh()
 
+    def GetSearchController(self):
+        """Get the L{SearchController} used by this control.
+        @return: L{SearchController}
+
+        """
+        return self.FindService
+
     def GetSearchData(self):
         """Gets the find data from the controls FindService
         @return: search data
@@ -1047,6 +1110,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             c_flags |= flags
             self._flags = c_flags
             data.SetFlags(self._flags)
+            self.FindService.RefreshControls()
 
     #---- End Functions ----#
 
@@ -1177,8 +1241,7 @@ class EdFindResults(plugin.Plugin):
         @param menu: the menu items parent menu
 
         """
-        return wx.MenuItem(menu, ed_glob.ID_FIND_RESULTS,
-                           _("Find Results"), _("Show a find results screen"))
+        return None
 
     def GetName(self):
         """Return the name of this control"""
@@ -1196,13 +1259,33 @@ class EdFindResults(plugin.Plugin):
 
         """
         win = wx.GetApp().GetActiveWindow()
+
+        # Cleanup window list for dead objects
+        to_pop = list()
+        for idx, item in enumerate(list(EdFindResults.RESULT_SCREENS)):
+            if not isinstance(item, SearchResultScreen):
+                to_pop.append(idx)
+
+        for idx in reversed(to_pop):
+            EdFindResults.RESULT_SCREENS.pop(idx)
+
+        # Try to find an empty existing window to use for the new search
+        screen = None
         if win is not None:
             shelf = win.GetShelf()
-            screen = shelf.RaiseItem(u"Find Results")
-            if screen is None or screen.GetDisplayedLines() > 3:
+            s_mw = shelf.GetOwnerWindow()
+            shelf_nb = shelf.GetWindow()
+            for item in EdFindResults.RESULT_SCREENS:
+                if item.GetDisplayedLines() < 3 and \
+                   s_mw is win and item.GetParent() is shelf_nb:
+                    screen = shelf.RaiseWindow(item)
+                    break
+
+            if screen is None:
                 shelf.PutItemOnShelf(ed_glob.ID_FIND_RESULTS)
-                shelf_nb = shelf.GetWindow()
                 screen = shelf_nb.GetCurrentPage()
+
+            # Fire off the search job
             data = msg.GetData()
             if len(data) > 1:
                 # Doing a file search operation
