@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 57407 2008-12-17 22:36:18Z CJP $"
-__revision__ = "$Revision: 57407 $"
+__svnid__ = "$Id: ed_stc.py 57765 2009-01-02 04:57:26Z CJP $"
+__revision__ = "$Revision: 57765 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -36,6 +36,7 @@ from autocomp import autocomp
 import util
 import ed_style
 import ed_msg
+import ed_mdlg
 import ed_txt
 import ed_menu
 from ed_keyh import KeyHandler, ViKeyHandler
@@ -51,9 +52,9 @@ NUM_MARGIN  = 1
 FOLD_MARGIN = 2
 
 # EOL Constants
-EDSTC_EOL_CR   = "CR"
-EDSTC_EOL_LF   = "LF"
-EDSTC_EOL_CRLF = "CRLF"
+EDSTC_EOL_CR   = ed_glob.EOL_MODE_CR
+EDSTC_EOL_LF   = ed_glob.EOL_MODE_LF
+EDSTC_EOL_CRLF = ed_glob.EOL_MODE_CRLF
 
 # Character sets
 SPACECHARS = " \t\r\n"
@@ -153,7 +154,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 self.CmdKeyAssign(*keys)
 
         # Other Settings
-        self._menu = MakeMenu()
         self.UsePopUp(False)
 
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
@@ -164,9 +164,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
         self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
-
-        # Context Menu Events
-        self.Bind(wx.EVT_CONTEXT_MENU, lambda evt: self.PopupMenu(self._menu))
         
         # Need to relay the menu events from the context menu to the top level
         # window to be handled on gtk. Other platforms don't require this.
@@ -177,7 +174,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
        #---- End Init ----#
 
     def __del__(self):
+        # Cleanup the file object callbacks
         self.file.RemoveModifiedCallback(self.FireModified)
+        self.file.CleanUp()
 
     @property
     def __name__(self):
@@ -351,7 +350,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         # Check if we are still alive or not, as this may be called
         # after we have been deleted.
         if isinstance(self, wx.stc.StyledTextCtrl):
-            wx.stc.StyledTextCtrl.BraceBadLight(self, pos)
+            super(EditraStc, self).BraceBadLight(pos)
 
     def BraceHighlight(self, pos1, pos2):
         """Highlight characters at pos1 and pos2
@@ -362,7 +361,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         # Check if we are still alive or not, as this may be called
         # after we have been deleted.
         if isinstance(self, wx.stc.StyledTextCtrl):
-            wx.stc.StyledTextCtrl.BraceHighlight(self, pos1, pos2)
+            super(EditraStc, self).BraceHighlight(pos1, pos2)
 
     def GetBookmarks(self):
         """Gets a list of all lines containing bookmarks
@@ -417,7 +416,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetTabWidth(_PGET('TABWIDTH', 'int'))
 #        self.SetTabIndents(True) # Add option for this too?
         self.SetIndentationGuides(_PGET('GUIDES'))
-        self.SetEOLMode(_PGET('EOL'))
+        self.SetEOLMode(_PGET('EOL_MODE'))
         self.SetViewEOL(_PGET('SHOW_EOL'))
         self.SetAutoComplete(_PGET('AUTO_COMP'))
         self.FoldingOnOff(_PGET('CODE_FOLD'))
@@ -427,23 +426,22 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetViEmulationMode(_PGET('VI_EMU'))
         self.SetViewEdgeGuide(_PGET('SHOW_EDGE'))
 
-    def Comment(self, uncomment=False):
+    def Comment(self, start, end, uncomment=False):
         """(Un)Comments a line or a selected block of text
         in a document.
-        @param uncomment: uncomment selection
+        @param start: begining line (int)
+        @param end: end line (int)
+        @keyword uncomment: uncomment selection
 
         """
         if len(self._code['comment']):
             sel = self.GetSelection()
-            start = self.LineFromPosition(sel[0])
-            end = self.LineFromPosition(sel[1])
             c_start = self._code['comment'][0]
             c_end = u''
             if len(self._code['comment']) > 1:
                 c_end = self._code['comment'][1]
-            if end > start and self.GetColumn(sel[1]) == 0:
-                end = end - 1
 
+            # Modify the selected line(s)
             self.BeginUndoAction()
             try:
                 nchars = 0
@@ -477,6 +475,38 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                         nchars = nchars - len(self._code['comment'][1])
                     self.GotoPos(sel[0] + nchars)
 
+    def ToggleComment(self):
+        """Toggle the comment of the selected region"""
+        if len(self._code['comment']):
+            sel = self.GetSelection()
+            start = self.LineFromPosition(sel[0])
+            end = self.LineFromPosition(sel[1])
+            c_start = self._code['comment'][0]
+            c_end = u''
+            if len(self._code['comment']) > 1:
+                c_end = self._code['comment'][1]
+
+            if end > start and self.GetColumn(sel[1]) == 0:
+                end = end - 1
+
+            # Analyze the seleted line(s)
+            comment = 0
+            for line in range(start, end+1):
+                txt = self.GetLine(line)
+                if txt.lstrip().startswith(c_start):
+                    comment += 1
+
+            lcount = end - start
+            mod = 1
+            if lcount == 0:
+                mod = 0
+
+            if comment > (lcount / 2) + mod:
+                # Uncomment
+                self.Comment(start, end, True)
+            else:
+                self.Comment(start, end, False)
+
     def CanCopy(self):
         """Check if copy/cut is possible"""
         return self.GetSelectionStart() != self.GetSelectionEnd()
@@ -872,7 +902,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.WordPartRight()
-        wx.stc.StyledTextCtrl.ParaDown(self)
+        super(EditraStc, self).ParaDown()
         if self.GetCurrentPos() != self.GetLength():
             self.WordPartLeft()
             self.GotoPos(self.GetCurrentPos() + len(self.GetEOLChar()))
@@ -885,7 +915,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.WordRightExtend()
-        wx.stc.StyledTextCtrl.ParaDownExtend(self)
+        super(EditraStc, self).ParaDownExtend()
         if self.GetCurrentPos() != self.GetLength():
             self.WordLeftExtend()
             self.SetCurrentPos(self.GetCurrentPos() + len(self.GetEOLChar()))
@@ -900,8 +930,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         curr_pos = self.GetCurrentPos()
         start = curr_pos - 1
         col = self.GetColumn(curr_pos)
-        cmd_lmt = list(self._code['compsvc'].GetAutoCompStops())# + \
-                       #self._code['compsvc'].GetAutoCompFillups())
+        cmd_lmt = list(self._code['compsvc'].GetAutoCompStops() + \
+                       self._code['compsvc'].GetAutoCompFillups())
         for key in self._code['compsvc'].GetAutoCompKeys():
             kval = unichr(key)
             if kval in cmd_lmt:
@@ -1013,8 +1043,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         else:
             wx.CallAfter(self.BraceHighlight, brace_at_caret, brace_opposite)
 
-        evt.Skip()
-
     def OnMarginClick(self, evt):
         """Open and Close Folders as Needed
         @param evt: event that called this handler
@@ -1191,9 +1219,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                   ed_glob.ID_SELECTALL: self.SelectAll,
                   ed_glob.ID_FOLDING : self.FoldingOnOff,
                   ed_glob.ID_SHOW_LN : self.ToggleLineNumbers,
-                  ed_glob.ID_COMMENT : self.Comment,
+                  ed_glob.ID_TOGGLECOMMENT : self.ToggleComment,
                   ed_glob.ID_AUTOINDENT : self.ToggleAutoIndent,
                   ed_glob.ID_LINE_AFTER : self.AddLine,
+                  ed_glob.ID_TOGGLE_FOLD : self.ToggleFold,
                   ed_glob.ID_TRIM_WS : self.TrimWhitespace,
                   ed_glob.ID_MACRO_START : self.StartRecord,
                   ed_glob.ID_MACRO_STOP : self.StopRecord,
@@ -1254,8 +1283,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.FindLexer(f_ext)
         elif e_id == ed_glob.ID_AUTOCOMP:
             self.SetAutoComplete(not self.GetAutoComplete())
-        elif e_id == ed_glob.ID_UNCOMMENT:
-            self.Comment(True)
         elif e_id == ed_glob.ID_LINE_BEFORE:
             self.AddLine(before=True)
         elif e_id in [ed_glob.ID_TO_UPPER, ed_glob.ID_TO_LOWER]:
@@ -1279,13 +1306,18 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         eol_map = {"\n" : wx.stc.STC_EOL_LF,
                    "\r\n" : wx.stc.STC_EOL_CRLF,
                    "\r" : wx.stc.STC_EOL_CR}
+
         eol = chr(self.GetCharAt(self.GetLineEndPosition(0)))
         if eol == "\r":
             tmp = chr(self.GetCharAt(self.GetLineEndPosition(0) + 1))
             if tmp == "\n":
                 eol += tmp
+
+        # Is the eol used in the document the same as what is currently set.
         if eol != self.GetEOLChar():
             diff = True
+
+        # Check the lines to see if they are all matching or not.
         for line in range(self.GetLineCount() - 1):
             end = self.GetLineEndPosition(line)
             tmp = chr(self.GetCharAt(end))
@@ -1299,16 +1331,31 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         if mixed or diff:
             if mixed:
-                self.SetViewEOL(True)
+                # Warn about mixed end of line characters and offer to convert
+                msg = _("Mixed EOL characters detected.\n\n"
+                        "Would you like to format them to all be the same?")
+                dlg = ed_mdlg.EdFormatEOLDlg(self.GetTopLevelParent(), msg,
+                                             _("Format EOL?"),
+                                             eol_map.get(eol, self.GetEOLMode()))
+
+                if dlg.ShowModal() == wx.ID_YES:
+                    sel = dlg.GetSelection()
+                    self.ConvertEOLs(sel)
+                    super(EditraStc, self).SetEOLMode(sel)
+                dlg.Destroy()
             else:
-                self.SetEOLMode(eol_map.get(eol, wx.stc.STC_EOL_LF))
+                # The end of line character is different from the prefered
+                # user setting for end of line. So change our eol mode to
+                # preserve that of what the document is using.
+                mode = eol_map.get(eol, wx.stc.STC_EOL_LF)
+                super(EditraStc, self).SetEOLMode(mode)
         else:
             pass
 
     def ConvertLineMode(self, mode_id):
         """Converts all line endings in a document to a specified
         format.
-        @param mode_id: id of eol mode to set
+        @param mode_id: (menu) id of eol mode to set
 
         """
         eol_map = { ed_glob.ID_EOL_MAC  : wx.stc.STC_EOL_CR,
@@ -1316,7 +1363,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     ed_glob.ID_EOL_WIN  : wx.stc.STC_EOL_CRLF
                   }
         self.ConvertEOLs(eol_map[mode_id])
-        self.SetEOLMode(eol_map[mode_id])
+        super(EditraStc, self).SetEOLMode(eol_map[mode_id])
 
     def ConvertWhitespace(self, mode_id):
         """Convert whitespace from using tabs to spaces or visa versa
@@ -1359,10 +1406,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @return: the character used for eol in this document
 
         """
-        m_id = self.GetEOLModeId()
-        if m_id == ed_glob.ID_EOL_MAC:
+        m_id = self.GetEOLMode()
+        if m_id == wx.stc.STC_EOL_CR:
             return u'\r'
-        elif m_id == ed_glob.ID_EOL_WIN:
+        elif m_id == wx.stc.STC_EOL_CRLF:
             return u'\r\n'
         else:
             return u'\n'
@@ -1378,7 +1425,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             return u' ' * self.GetIndent()
 
     def GetEOLModeId(self):
-        """Gets the id of the eol format
+        """Gets the id of the eol format. Convinience for updating
+        menu ui.
         @return: id of the eol mode of this document
 
         """
@@ -1476,7 +1524,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.BeginUndoAction()
-        wx.stc.StyledTextCtrl.LineTranspose(self)
+        super(EditraStc, self).LineTranspose()
         self.EndUndoAction()
 
     def SetAutoComplete(self, value):
@@ -1515,8 +1563,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                      EDSTC_EOL_LF   : wx.stc.STC_EOL_LF,
                      EDSTC_EOL_CRLF : wx.stc.STC_EOL_CRLF
                    }
+
         mode = mode_map.get(mode, wx.stc.STC_EOL_LF)
-        wx.stc.StyledTextCtrl.SetEOLMode(self, mode)
+        super(EditraStc, self).SetEOLMode(mode)
 
     def SetFileName(self, path):
         """Set the buffers filename attributes from the given path"""
@@ -1527,7 +1576,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @note: overriden as a hack for msw
 
         """
-        wx.stc.StyledTextCtrl.SetFocus(self)
+        super(EditraStc, self).SetFocus()
         if wx.Platform == '__WXMSW__':
             wx.PostEvent(self, wx.FocusEvent(wx.wxEVT_SET_FOCUS, self.GetId()))
 
@@ -1549,7 +1598,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 self.Unbind(wx.stc.EVT_STC_STYLENEEDED)
                 self._code['clexer'] = None
 
-        wx.stc.StyledTextCtrl.SetLexer(self, lexer)
+        super(EditraStc, self).SetLexer(lexer)
 
     def SetModTime(self, modtime):
         """Set the value of the files last modtime"""
@@ -1588,7 +1637,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                                    _("Recording Macro") + u"...",
                                    ed_glob.SB_INFO)
         wx.PostEvent(self.GetTopLevelParent(), evt)
-        wx.stc.StyledTextCtrl.StartRecord(self)
+        super(EditraStc, self).StartRecord()
 
     def StopRecord(self):
         """Stops the recording and builds the macro script
@@ -1596,7 +1645,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.recording = False
-        wx.stc.StyledTextCtrl.StopRecord(self)
+        super(EditraStc, self).StopRecord()
         evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
                                    _("Recording Finished"),
                                    ed_glob.SB_INFO)
@@ -1710,6 +1759,16 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """Toggle the column edit mode"""
         self.vert_edit.enable(not self.vert_edit.Enabled)
 
+    def ToggleFold(self, lineNum=None):
+        """Toggle the fold at the given line number. If lineNum is
+        None then the fold closest cursors current postions.
+        @keyword lineNum: int
+
+        """
+        if lineNum is None:
+            lineNum = self.GetCurrentLine()
+        super(EditraStc, self).ToggleFold(lineNum)
+
     def ToggleLineNumbers(self, switch=None):
         """Toggles the visibility of the line number margin
         @keyword switch: force a particular setting
@@ -1728,10 +1787,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.SetWordChars(NONSPACE)
-        wx.stc.StyledTextCtrl.WordLeft(self)
+        super(EditraStc, self).WordLeft()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordLeft(self)
+            super(EditraStc, self).WordLeft()
         self.SetWordChars('')
 
     def WordLeftExtend(self):
@@ -1740,10 +1799,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.SetWordChars(NONSPACE)
-        wx.stc.StyledTextCtrl.WordLeftExtend(self)
+        super(EditraStc, self).WordLeftExtend()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordLeftExtend(self)
+            super(EditraStc, self).WordLeftExtend()
         self.SetWordChars('')
 
     def WordPartLeft(self):
@@ -1751,38 +1810,38 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @note: overrides default function to not count whitespace as words
 
         """
-        wx.stc.StyledTextCtrl.WordPartLeft(self)
+        super(EditraStc, self).WordPartLeft()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordPartLeft(self)
+            super(EditraStc, self).WordPartLeft()
 
     def WordPartLeftExtend(self):
         """Extend selection left to the next change in capitalization/puncuation
         @note: overrides default function to not count whitespace as words
 
         """
-        wx.stc.StyledTextCtrl.WordPartLeftExtend(self)
+        super(EditraStc, self).WordPartLeftExtend()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordPartLeftExtend(self)
+            super(EditraStc, self).WordPartLeftExtend()
 
     def WordPartRight(self):
         """Move the caret to the start of the next word part to the right
         @note: overrides default function to exclude white space
 
         """
-        wx.stc.StyledTextCtrl.WordPartRight(self)
+        super(EditraStc, self).WordPartRight()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordPartRight(self)
+            super(EditraStc, self).WordPartRight()
 
     def WordPartRightEnd(self):
         """Move caret to end of next change in capitalization/puncuation
         @postcondition: caret is moved
 
         """
-        wx.stc.StyledTextCtrl.WordPartRight(self)
-        wx.stc.StyledTextCtrl.WordPartRight(self)
+        super(EditraStc, self).WordPartRight()
+        super(EditraStc, self).WordPartRight()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos - 1) in SPACECHARS:
             self.CharLeft()
@@ -1792,8 +1851,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondition: selection is extended
 
         """
-        wx.stc.StyledTextCtrl.WordPartRightExtend(self)
-        wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+        super(EditraStc, self).WordPartRightExtend()
+        super(EditraStc, self).WordPartRightExtend()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos - 1) in SPACECHARS:
             self.CharLeftExtend()
@@ -1803,10 +1862,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondition: selection is extended
 
         """
-        wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+        super(EditraStc, self).WordPartRightExtend()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordPartRightExtend(self)
+            super(EditraStc, self).WordPartRightExtend()
 
     def WordRight(self):
         """Move caret to begining of next word
@@ -1814,10 +1873,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.SetWordChars(NONSPACE)
-        wx.stc.StyledTextCtrl.WordRight(self)
+        super(EditraStc, self).WordRight()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordRight(self)
+            super(EditraStc, self).WordRight()
         self.SetWordChars('')
 
     def WordRightEnd(self):
@@ -1826,10 +1885,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.SetWordChars(NONSPACE)
-        wx.stc.StyledTextCtrl.WordRightEnd(self)
+        super(EditraStc, self).WordRightEnd()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos - 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordRightEnd(self)
+            super(EditraStc, self).WordRightEnd()
         self.SetWordChars('')
 
     def WordRightExtend(self):
@@ -1838,10 +1897,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.SetWordChars(NONSPACE)
-        wx.stc.StyledTextCtrl.WordRightExtend(self)
+        super(EditraStc, self).WordRightExtend()
         cpos = self.GetCurrentPos()
         if self.GetTextRange(cpos, cpos + 1) in SPACECHARS:
-            wx.stc.StyledTextCtrl.WordRightExtend(self)
+            super(EditraStc, self).WordRightExtend()
         self.SetWordChars('')
 
     def LoadFile(self, path):
@@ -2107,7 +2166,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     continue
                 else:
                     self._code['keywords'] += keyw[1]
-                    wx.stc.StyledTextCtrl.SetKeyWords(self, keyw[0], keyw[1])
+                    super(EditraStc, self).SetKeyWords(keyw[0], keyw[1])
 
         kwlist = self._code['keywords'].split()    # Split into a list of words
         kwlist = list(set(kwlist))                 # Uniqueify the list
@@ -2169,22 +2228,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
 #-----------------------------------------------------------------------------#
 
-def MakeMenu():
-    """Make the buffers context menu"""
-    menu = ed_menu.EdMenu()
-    menu.Append(ed_glob.ID_UNDO, _("Undo"))
-    menu.Append(ed_glob.ID_REDO, _("Redo"))
-    menu.AppendSeparator()
-    menu.Append(ed_glob.ID_CUT, _("Cut"))
-    menu.Append(ed_glob.ID_COPY, _("Copy"))
-    menu.Append(ed_glob.ID_PASTE, _("Paste"))
-    menu.AppendSeparator()
-    menu.Append(ed_glob.ID_TO_UPPER, _("To Uppercase"))
-    menu.Append(ed_glob.ID_TO_LOWER, _("To Lowercase"))
-    menu.AppendSeparator()
-    menu.Append(ed_glob.ID_SELECTALL, _("Select All"))
-    return menu
-
 def _GetMacKeyBindings():
     """Returns a list of 3-element tuples defining the standard key
     bindings for Mac text editors -- i.e., the behavior of option-arrow,
