@@ -16,8 +16,8 @@ can be installed as single file instead of dozens of individual image files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 57226 2008-12-10 03:13:03Z CJP $"
-__revision__ = "$Revision: 57226 $"
+__svnid__ = "$Id: ed_theme.py 57365 2008-12-16 02:02:11Z CJP $"
+__revision__ = "$Revision: 57365 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -306,7 +306,7 @@ class TangoTheme(plugin.Plugin):
 
         # Get the path
         if ed_glob.CONFIG['THEME_DIR'] == u'':
-            theme = util.ResolvConfigDir(os.path.join("pixmaps", "theme"))
+            theme = util.ResolvConfigDir(os.path.join(u"pixmaps", u"theme"))
             ed_glob.CONFIG['THEME_DIR'] = theme
 
         if mime:
@@ -387,9 +387,15 @@ class TangoTheme(plugin.Plugin):
 
         """
         if bmp_id in ART:
+#            size = Profile_Get('ICON_SZ', default=(24, 24))
             path = self.__GetArtPath(wx.ART_TOOLBAR, mime=False)
             if path is not None:
+#                tpath = os.path.join(path, '24', ART[bmp_id])
+#                if size[0] == 24 and os.path.exists(tpath):
+#                    path = tpath
+#                else:
                 path = path + ART[bmp_id]
+
                 if os.path.exists(path):
                     return wx.Bitmap(path, wx.BITMAP_TYPE_PNG)
 
