@@ -12,8 +12,8 @@ Text/Unicode handling functions and File wrapper class
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_txt.py 57037 2008-11-30 03:59:11Z CJP $"
-__revision__ = "$Revision: 57037 $"
+__svnid__ = "$Id: ed_txt.py 57765 2009-01-02 04:57:26Z CJP $"
+__revision__ = "$Revision: 57765 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -107,6 +107,10 @@ class EdFile(object):
 
         self.open = False
 
+    def CleanUp(self):
+        """Cleanup callback"""
+        pass
+
     def DoOpen(self, mode):
         """Opens and creates the internal file object
         @param mode: mode to open file in
