@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 57420 2008-12-18 16:37:26Z CJP $"
-__revision__ = "$Revision: 57420 $"
+__svnid__ = "$Id: prefdlg.py 57676 2008-12-30 20:40:41Z CJP $"
+__revision__ = "$Revision: 57676 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -35,6 +35,7 @@ from profiler import Profile_Get, Profile_Set
 import ed_i18n
 import ed_event
 import ed_crypt
+import ed_stc
 import updater
 import util
 import syntax.syntax as syntax
@@ -292,7 +293,7 @@ class GeneralPanel(wx.Panel):
         msizer.AddMany([(wx.StaticText(self, label=_("Editor Mode") + u": "),
                          0, wx.ALIGN_CENTER_VERTICAL), ((5, 5), 0),
                         (ExChoice(self, ed_glob.ID_PREF_MODE,
-                                  choices=['CODE', 'DEBUG'],
+                                  choices=['CODE', 'DEBUG', 'VERBOSE DEBUG'],
                                   default=Profile_Get('MODE')),
                           0, wx.ALIGN_CENTER_VERTICAL)])
 
@@ -355,6 +356,9 @@ class GeneralPanel(wx.Panel):
                                 _("Check if on disk file has been "
                                   "modified by others"))
         chkmod_cb.SetValue(Profile_Get('CHECKMOD'))
+        eolwarn_cb = wx.CheckBox(self, ed_glob.ID_PREF_WARN_EOL,
+                                 _("Warn when mixed eol characters are detected"))
+        eolwarn_cb.SetValue(Profile_Get('WARN_EOL'))
 
         # Locale
         lsizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -365,7 +369,7 @@ class GeneralPanel(wx.Panel):
                          0, wx.ALIGN_CENTER_VERTICAL)])
 
         # Layout items
-        sizer = wx.FlexGridSizer(17, 2, 5, 5)
+        sizer = wx.FlexGridSizer(18, 2, 5, 5)
         sizer.AddMany([((10, 10), 0), ((10, 10), 0),
                        (wx.StaticText(self,
                         label=_("Startup Settings") + u": "),
@@ -382,6 +386,7 @@ class GeneralPanel(wx.Panel):
                        ((5, 5),), (win_cb, 0),
                        ((5, 5),), (pos_cb, 0),
                        ((5, 5),), (chkmod_cb, 0),
+                       ((5, 5),), (eolwarn_cb, 0),
                        ((5, 5),), ((5, 5),),
                        (wx.StaticText(self, label=_("Locale Settings") + u": "),
                         0, wx.ALIGN_CENTER_VERTICAL), (lsizer, 0),
@@ -399,9 +404,10 @@ class GeneralPanel(wx.Panel):
         util.Log("[prefdlg][evt] General Page: Check box clicked")
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
-        if e_id in [ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
+        if e_id in (ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
                     ed_glob.ID_PREF_CHKMOD, ed_glob.ID_SESSION,
-                    ed_glob.ID_NEW_WINDOW, ed_glob.ID_PREF_CHKUPDATE]:
+                    ed_glob.ID_NEW_WINDOW, ed_glob.ID_PREF_CHKUPDATE,
+                    ed_glob.ID_PREF_WARN_EOL):
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
         elif e_id == ed_glob.ID_REPORTER:
             Profile_Set(ed_glob.ID_2_PROF[e_id], not e_obj.GetValue())
@@ -425,7 +431,9 @@ class GeneralPanel(wx.Panel):
 
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             if e_id == ed_glob.ID_PREF_MODE:
-                ed_glob.DEBUG = ('DEBUG' in e_obj.GetValue())
+                val = e_obj.GetValue()
+                ed_glob.DEBUG = ('DEBUG' in val)
+                ed_glob.VDEBUG = ('VERBOSE' in val)
         elif e_id == ed_glob.ID_PRINT_MODE:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetSelection())
         else:
@@ -531,15 +539,19 @@ class DocGenPanel(wx.Panel):
         bsu_cb = wx.CheckBox(self, ed_glob.ID_PREF_UNINDENT,
                              _("Backspace Unindents"))
         bsu_cb.SetValue(Profile_Get('BSUNINDENT', 'bool', True))
+
         eolsz = wx.BoxSizer(wx.HORIZONTAL)
+
+        # NOTE: order must be kept insync with vals in ed_glob, ed_stc
+        eolmode = ExChoice(self, ed_glob.ID_EOL_MODE,
+                           choices=[_("Old Macintosh (\\r)"), _("Unix (\\n)"),
+                                    _("Windows (\\r\\n)")])
+        eolmode.SetSelection(Profile_Get('EOL_MODE'))
+                        
         eolsz.AddMany([(wx.StaticText(self,
                         label=_("Default EOL Mode") + u": "),
                         0, wx.ALIGN_CENTER_VERTICAL), ((5, 5), 0),
-                       (ExChoice(self, ed_glob.ID_EOL_MODE,
-                                 choices=[_("Macintosh (\\r)"), _("Unix (\\n)"),
-                                          _("Windows (\\r\\n)")],
-                                 default=Profile_Get('EOL')),
-                        0, wx.ALIGN_CENTER_VERTICAL)])
+                       (eolmode, 0, wx.ALIGN_CENTER_VERTICAL)])
 
         # View Options
         aa_cb = wx.CheckBox(self, ed_glob.ID_PREF_AALIAS, _("AntiAliasing"))
@@ -641,8 +653,12 @@ class DocGenPanel(wx.Panel):
                     ed_glob.ID_SHOW_LN, ed_glob.ID_SHOW_WS,
                     ed_glob.ID_WORD_WRAP, ed_glob.ID_PREF_AALIAS,
                     ed_glob.ID_PREF_INDENTW, ed_glob.ID_PREF_AUTOTRIM ]:
-            Profile_Set(ed_glob.ID_2_PROF[e_id],
-                        evt.GetEventObject().GetValue())
+
+            e_value = evt.GetEventObject().GetValue()
+            if e_id == ed_glob.ID_EOL_MODE:
+                e_value = evt.GetEventObject().GetSelection()
+
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_value)
 
             # Do updates for everything but text encoding
             if e_id not in (ed_glob.ID_PREF_AUTOTRIM, ):
@@ -1865,9 +1881,10 @@ class ExChoice(wx.Choice):
 
         """
         if len(choices) and isinstance(choices[0], int):
-            for ind in range(len(choices)):
-                choices[ind] = str(choices[ind])
+            choices = [ unicode(choice) for choice in choices ]
+
         wx.Choice.__init__(self, parent, cid, choices=choices)
+
         if default != None and isinstance(default, basestring):
             self.SetStringSelection(default)
         elif default is not None:
