@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 57296 2008-12-12 22:33:02Z CJP $"
-__revision__ = "$Revision: 57296 $"
+__svnid__ = "$Id: profiler.py 57476 2008-12-21 17:18:35Z CJP $"
+__revision__ = "$Revision: 57476 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -31,7 +31,7 @@ import cPickle
 import wx
 
 # Editra Imports
-from ed_glob import CONFIG, PROG_NAME, VERSION, PRINT_BLACK_WHITE
+from ed_glob import CONFIG, PROG_NAME, VERSION, PRINT_BLACK_WHITE, EOL_MODE_LF
 import util
 import dev_tool
 
@@ -55,7 +55,7 @@ _DEFAULTS = {
            'DEFAULT_VIEW' : 'Automatic',    # Default Perspective
            'EDGE'       : 80,               # Edge guide column
            'ENCODING'   : None,             # Prefered text encoding
-           'EOL'        : 'LF',             # EOL mode
+           'EOL_MODE'   : EOL_MODE_LF,      # EOL mode 1 == LF, 2 == CRLF
            'FHIST'      : list(),           # List of history files
            'FHIST_LVL'  : 9,                # Filehistory length (9 is max)
            'FFILTER'    : 0,                # Last file filter used
@@ -96,6 +96,7 @@ _DEFAULTS = {
            'USETABS'    : False,            # Use tabs instead of spaces
            'USE_PROXY'  : False,            # Use Proxy server settings?
            'VI_EMU'     : False,            # Use Vi emulation mode
+           'WARN_EOL'   : True,             # Warn about mixed eol characters
            'WRAP'       : False,            # Use Wordwrap
            'WSIZE'      : (700, 450)        # Mainwindow size
           #FONT1 created at runtime by ed_styles as primary font
