@@ -18,8 +18,8 @@ provides a higher level interface into the L{UpdateService}.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: updater.py 56709 2008-11-08 16:14:11Z CJP $"
-__revision__ = "$Revision: 56709 $"
+__svnid__ = "$Id: updater.py 57682 2008-12-31 02:21:20Z CJP $"
+__revision__ = "$Revision: 57682 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -561,7 +561,7 @@ class DownloadDialog(wx.Frame):
         dl_file = wx.StaticText(panel, label=_("Downloading: %s") % fname)
         dl_loc = wx.StaticText(panel, wx.ID_ANY,
                                _("Downloading To: %s") % floc)
-        self._cancel_bt = wx.Button(panel, wx.ID_CANCEL)
+        self._cancel_bt = wx.Button(panel, wx.ID_CANCEL, _("Cancel"))
         self._timer = wx.Timer(self, id=self.ID_TIMER)
         self._proghist = list()
 
