@@ -7,17 +7,14 @@
 ###############################################################################
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testStyleItem.py 55148 2008-08-21 18:59:10Z CJP $"
-__revision__ = "$Revision: 55148 $"
+__svnid__ = "$Id: testStyleItem.py 57490 2008-12-21 23:00:43Z CJP $"
+__revision__ = "$Revision: 57490 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
-import sys
-import os
 import unittest
 
 # Module to test
-sys.path.insert(0, os.path.abspath("../../src"))
 import ed_style
 
 #-----------------------------------------------------------------------------#
@@ -163,8 +160,3 @@ class StyleItemTest(unittest.TestCase):
         self.assertEquals(self.item.GetFace(), "FakeFont")
         self.item.SetNamedAttr('fore', None)
         self.assertEquals(self.item.GetFore(), "")
-
-#-----------------------------------------------------------------------------#
-
-if __name__ == '__main__':
-    unittest.main()
